@@ -18,7 +18,7 @@ import autonetkit.config as config
 #TODO: make if measure set, then not compile - or warn if both set, as don't want to regen topology when measuring
 
 try:
-    ank_version = pkg_resources.get_distribution("autonetkit-v3-dev").version
+    ank_version = pkg_resources.get_distribution("autonetkit").version
 except pkg_resources.DistributionNotFound:
     ank_version = "dev"
 
@@ -193,7 +193,6 @@ def main():
                 rebuild = False
                 reload_build = False
                 if input_filemonitor.has_changed():
-                    print "input changed"
                     rebuild = True
                 if build_filemonitor.has_changed():
                     reload_build = True
